﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Janus.Core.Models
{
    /// <summary>
    /// This class represents the edge of the dependency graph.
    /// It will provide additional information about the edge and its reason.
    /// Also, this edge has the reference for its node
    /// </summary>
    public class GraphEdge<T>
    {
        /// <summary>
        /// Constructs and initializes the instance
        /// </summary>
        public GraphEdge()
        {
            AnnotationInfo = new List<AnnotationInfoItem>();
            CustomAttributes = new Dictionary<string, object>();
        }

        /// <summary>
        /// Annotation info added by analyzers
        /// </summary>
        public IList<AnnotationInfoItem> AnnotationInfo { get; set; }

        /// <summary>
        /// Custom attributes based on needs of the rest of the framework
        /// </summary>
        public IDictionary<string, object> CustomAttributes { get; set; }

        /// <summary>
        /// Refference to the parent item.
        /// Type is based on T
        /// </summary>
        public T Parent { get; set; }

        /// <summary>
        /// Refference to the linked item.
        /// Type is based on T
        /// </summary>
        public T Link { get; set; }
    }
}
