﻿using System;
using System.Collections.Generic;
using System.Text;

namespace Janus.Core.Models
{
    /// <summary>
    /// Represents one package version limitation
    /// </summary>
    public class VersionLimit
    {

        /// <summary>
        /// Represents the type of operation of the version
        /// </summary>
        public enum OperatorType
        {
            /// <summary>
            /// Greater of equal
            /// </summary>
            GreaterOrEqual,

            /// <summary>
            /// Greater
            /// </summary>
            Greater,

            /// <summary>
            /// Lower or equal
            /// </summary>
            LowerOrEqual,

            /// <summary>
            /// Lower
            /// </summary>
            Lower,

            /// <summary>
            /// Equal
            /// </summary>
            Equal,

            /// <summary>
            /// Not equal
            /// </summary>
            NotEqual,

            /// <summary>
            /// Compatible
            /// </summary>
            Compatible,

            /// <summary>
            /// Custom type
            /// </summary>
            Custom,

            /// <summary>
            /// Undefined
            /// </summary>
            Undefined
        }

        /// <summary>
        /// Constructs instance
        /// </summary>
        public VersionLimit()
        {

        }

        /// <summary>
        /// Symbol of the operation for the limit
        /// </summary>
        public OperatorType LimitSymbol { get; set; }

        /// <summary>
        /// Optional, custo msymbol of the operation
        /// </summary>
        public string CustomLimitSymbol { get; set; } = "";

        /// <summary>
        /// Required version of the depdency
        /// Textual representation
        /// </summary>
        public string RequiredVersion { get; set; }

        /// <summary>
        /// Textual representation
        /// </summary>
        /// <returns></returns>
        public override string ToString()
        {
            switch (LimitSymbol)
            {
                case OperatorType.GreaterOrEqual:
                    return $">={RequiredVersion}";
                case OperatorType.Greater:
                    return $">{RequiredVersion}";
                case OperatorType.LowerOrEqual:
                    return $"<={RequiredVersion}";
                case OperatorType.Lower:
                    return $"<{RequiredVersion}";
                case OperatorType.Equal:
                    return $"=={RequiredVersion}";
                case OperatorType.NotEqual:
                    return $"!={RequiredVersion}";
                case OperatorType.Compatible:
                    return $"~={RequiredVersion}";
                case OperatorType.Custom:
                    return $"{CustomLimitSymbol}{RequiredVersion}";
                default:
                    return $"{RequiredVersion}";
            }
        }
    }
}
