﻿using CommandLine;
using Janus.Core.Utils;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Janus.Parsers.PythonPyPi
{
    /// <summary>
    /// Command line options for the tool
    /// 
    /// Extends the basic options provided by the core
    /// </summary>
    public class CLIOptions : CLIOptionsCoreBase
    {
        /// <summary>
        /// Specific dependencies, list
        /// </summary>
        [Option("analyzeDependencies",
            HelpText = "List of dependencies to be analyzed (\"<id>;<version>\")")]
        public IEnumerable<string> InputDependencies { get; set; }

        /// <summary>
        /// Search depth
        /// </summary>
        [Option('d', "depth",
          Default = -1,
          HelpText = "Depth of the search in the dependency tree (Possible value: 1 - n), -1 is maximum.")]
        public int SearchDepth { get; set; }

        /// <summary>
        /// URL to the repository
        /// </summary>
        [Option('r', "repositoryUrl",
          Default = "https://pypi.org/simple",
          HelpText = "PyPI repository URL")]
        public string RepositoryURL { get; set; }

        /// <summary>
        /// Disable local cache dir
        /// </summary>
        [Option("noCacheDir",
          Default = false,
          HelpText = "Does not consider local cache dir state during dependency graph creation")]
        public bool DisableCacheDir { get; set; }


    }
}
