﻿using CommandLine;
using Janus.Core.Models;
using Janus.Core.Models.Results;
using Janus.Core.Utils;
using Janus.Parsers.PythonPyPi.Parser;
using Janus.Parsers.PythonPyPi.PyPIAPI;
using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;

namespace Janus.Parsers.PythonPyPi
{
    class Program
    {
        /// <summary>
        /// Command line arguments parsed as options
        /// </summary>
        public static CLIOptions options;

        /// <summary>
        /// Main entry point of the program
        /// </summary>
        /// <param name="args">CLI Arguments</param>
        /// <returns></returns>
        static void Main(string[] args)
        {
            //string name = "pipgrip";
            //string version = "0.1";

            //PyPIAPI.PyPIWrapper.Instance.GetDepTreeForPackage(name, version);
            //PyPIAPI.PyPIWrapper.Instance.GetPackageMetadata(name, version);

            var result = CommandLine.Parser.Default.ParseArguments<CLIOptions>(args)
                                                .WithParsed(RunOptions)
                                                .WithNotParsed(HandleParseError);
        }

        /// <summary>
        /// Main logic, if argument parsing is without an error
        /// </summary>
        /// <param name="opts">CLI Arguments as options</param>
        /// <returns></returns>
        static void RunOptions(CLIOptions opts)
        {
            options = opts; //Pass args to the rest of the program

            IList<DependencyItem> dependencies = new List<DependencyItem>();

            if (opts.InputDependencies.Any())
            {
                List<Tuple<string, string>> depInfos = new List<Tuple<string, string>>();
                foreach (var inputDep in options.InputDependencies)
                {
                    //Parse dep info
                    // Format "<id>;<version>"
                    var splitText = inputDep.Split(";");
                    if (splitText.Length != 2)
                    {
                        //Error ... wrong format
                        Console.Error.WriteLine($"Error: Wrong dependency info format provided, problem is with the: \"{inputDep}\" (Skipping ...)");
                        continue;
                    }

                    depInfos.Add(Tuple.Create(splitText[0], splitText[1])); //Add to work list
                }

                //Send to the processing

                GenericResult<List<DependencyItem>> parserResult = PyPIParser.ParseDependencies(depInfos);

                if (!parserResult.OperationSuccessful)
                {
                    //parse problem .... end execution
                    foreach (var err in parserResult.Errors)
                    {
                        Console.Error.WriteLine(err);
                    }
                    return;
                }

                dependencies = parserResult.Result;
            }

            if (dependencies.Count > 0)
            {
                //Print dependencies
                DataWorker.Print(dependencies, options);
            }
            else
            {
                Console.Error.WriteLine($"Nothing to print!");
                Console.Error.WriteLine("Skipping printings...");
            }
        }

        /// <summary>
        /// This method is called in case of argument parsing failure
        /// </summary>
        /// <param name="errs">Parsing errors as text</param>
        static void HandleParseError(IEnumerable<Error> errs)
        {
            Console.Error.WriteLine("ERROR During arguments matching ...");
            foreach (var item in errs)
            {
                Console.Error.WriteLine(item);
            }
        }

    }
}
